(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     71696,       1905]
NotebookOptionsPosition[     69723,       1838]
NotebookOutlinePosition[     70058,       1853]
CellTagsIndexPosition[     70015,       1850]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Gravito-scalar QNMs of Schwarzschild-AdS BHs in Dynamical Chern-Simons \
gravity\nExtension of the series method by Horowitz & Hubeny\n",
 StyleBox["References: Paolo Pani, \[OpenCurlyDoubleQuote]Advanced methods in \
Black-Hole Perturbation Theory\[CloseCurlyDoubleQuote] (2013)",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{
  3.5701092341113586`*^9, {3.570117652780466*^9, 3.5701176573116493`*^9}, {
   3.570118625235464*^9, 3.5701186769267683`*^9}, {3.570227375137948*^9, 
   3.570227401005803*^9}, {3.570297609427958*^9, 3.57029767032325*^9}}],

Cell[CellGroupData[{

Cell["Series method", "Section",
 CellChangeTimes->{{3.5702914450363493`*^9, 3.570291447300437*^9}}],

Cell["Equations:", "Text",
 CellChangeTimes->{{3.571520314984079*^9, 3.571520316221609*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     FractionBox["M", "r"]}], "+", 
    FractionBox[
     SuperscriptBox["r", "2"], 
     SuperscriptBox["L", "2"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V1", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"l", "+", 
      SuperscriptBox["l", "2"]}], 
     SuperscriptBox["r", "2"]], "-", 
    FractionBox[
     RowBox[{"6", " ", "M"}], 
     SuperscriptBox["r", "3"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V2", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"l", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "l"}], ")"}]}], 
     SuperscriptBox["r", "2"]], "+", 
    FractionBox[
     RowBox[{"2", " ", "M"}], 
     SuperscriptBox["r", "3"]], "-", 
    FractionBox[
     RowBox[{"2", " ", "\[CapitalLambda]"}], "3"], "+", 
    FractionBox[
     RowBox[{"72", "  ", "l", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "l"}], ")"}], " ", 
      SuperscriptBox["M", "2"], " ", 
      SuperscriptBox["\[Alpha]", "2"], " ", "\[Kappa]"}], 
     RowBox[{"\[Beta]", " ", 
      SuperscriptBox["r", "8"]}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1", "=", 
   FractionBox[
    RowBox[{"12", " ", "M", " ", "\[Alpha]", " ", "\[Kappa]"}], 
    SuperscriptBox["r", "5"]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S2", "=", 
   FractionBox[
    RowBox[{"6", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "l"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "l"}], ")"}], " ", "M", " ", "\[Alpha]"}], 
    RowBox[{"\[Beta]", " ", 
     SuperscriptBox["r", "5"]}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.570296109873616*^9, 3.570296172985743*^9}, {
  3.570296616936232*^9, 3.5702966453571787`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "x", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "[", "r", "]"}], "\[Equal]", "0"}], ",", "M"}], "]"}], "//",
   "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.570291837270475*^9, 3.57029184132502*^9}, {
  3.570291914923558*^9, 3.57029191869554*^9}, {3.570291969340283*^9, 
  3.570291971159181*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"M", "\[Rule]", 
    FractionBox[
     RowBox[{"r", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["L", "2"], "+", 
        SuperscriptBox["r", "2"]}], ")"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["L", "2"]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.570291841604039*^9, {3.570291916460265*^9, 3.57029191896061*^9}, 
   3.570291971481366*^9, 3.570293248421912*^9, 3.570296649010312*^9}]
}, Open  ]],

Cell["Rescaling:", "Text",
 CellChangeTimes->{{3.571520327310574*^9, 3.571520341598154*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"ruleRESCAL", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Kappa]", "\[Rule]", 
      RowBox[{"8", " ", "\[Pi]"}]}], ",", 
     RowBox[{"\[Beta]", "\[Rule]", "1"}], ",", 
     RowBox[{"\[CapitalLambda]", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "3"}], "/", 
       SuperscriptBox["L", "2"]}]}], ",", 
     RowBox[{"M", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "6"]}], " ", "rh", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{
          SuperscriptBox["rh", "2"], " ", "\[CapitalLambda]"}]}], ")"}]}]}], 
     ",", 
     RowBox[{"L", "\[Rule]", "1"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5702929605618258`*^9, 3.5702929675996647`*^9}, {
  3.5702961935651407`*^9, 3.570296193705698*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Q", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"q", "[", "r", "]"}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", "-", "rh"}], ")"}], 
     RowBox[{
      RowBox[{"-", "I"}], " ", 
      FractionBox["\[Omega]", 
       RowBox[{
        RowBox[{"F", "'"}], "[", "rh", "]"}]]}]]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalTheta]", "[", "r_", "]"}], ":=", 
    RowBox[{
     RowBox[{"\[CurlyPhi]", "[", "r", "]"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"r", "-", "rh"}], ")"}], 
      RowBox[{
       RowBox[{"-", "I"}], " ", 
       FractionBox["\[Omega]", 
        RowBox[{
         RowBox[{"F", "'"}], "[", "rh", "]"}]]}]]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{"Q", "''"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "'"}], "[", "r", "]"}], 
      RowBox[{"F", "[", "r", "]"}], 
      RowBox[{
       RowBox[{"Q", "'"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", 
        RowBox[{
         RowBox[{"F", "[", "r", "]"}], "V1"}]}], ")"}], 
      RowBox[{"Q", "[", "r", "]"}]}], "-", 
     RowBox[{
      RowBox[{"F", "[", "r", "]"}], "S1", " ", 
      RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}]}], "//.", "ruleRESCAL"}]}],
   ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"E2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"F", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{"\[CapitalTheta]", "''"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{
       RowBox[{"F", "'"}], "[", "r", "]"}], 
      RowBox[{"F", "[", "r", "]"}], 
      RowBox[{
       RowBox[{"\[CapitalTheta]", "'"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["\[Omega]", "2"], "-", 
        RowBox[{
         RowBox[{"F", "[", "r", "]"}], "V2"}]}], ")"}], 
      RowBox[{"\[CapitalTheta]", "[", "r", "]"}]}], "-", 
     RowBox[{
      RowBox[{"F", "[", "r", "]"}], "S2", " ", 
      RowBox[{"Q", "[", "r", "]"}]}]}], "//.", "ruleRESCAL"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5702916724617243`*^9, 3.5702917272676764`*^9}, {
  3.570291845738455*^9, 3.570291864991404*^9}, {3.570292075721463*^9, 
  3.570292116906001*^9}, {3.570292346331004*^9, 3.5702923788902597`*^9}, {
  3.5702929556158447`*^9, 3.5702929741970167`*^9}}],

Cell["New variable (x=1/r):", "Text",
 CellChangeTimes->{{3.5702919539780283`*^9, 3.570291956865053*^9}, {
  3.571520348809026*^9, 3.571520353240944*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", "r", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleV", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"q", "[", "r", "]"}], "\[Rule]", 
      RowBox[{"q", "[", "x", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"q", "'"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], 
       RowBox[{
        RowBox[{"q", "'"}], "[", "x", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"q", "''"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "x", " ", 
          RowBox[{
           RowBox[{"q", "'"}], "[", "x", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["x", "2"], 
          RowBox[{
           RowBox[{"q", "''"}], "[", "x", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"\[CurlyPhi]", "[", "r", "]"}], "\[Rule]", 
      RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CurlyPhi]", "'"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], 
       RowBox[{
        RowBox[{"\[CurlyPhi]", "'"}], "[", "x", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CurlyPhi]", "''"}], "[", "r", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["x", "2"]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], "x", " ", 
          RowBox[{
           RowBox[{"\[CurlyPhi]", "'"}], "[", "x", "]"}]}], "-", 
         RowBox[{
          SuperscriptBox["x", "2"], 
          RowBox[{
           RowBox[{"\[CurlyPhi]", "''"}], "[", "x", "]"}]}]}], ")"}]}]}], ",", 
     RowBox[{"rh", "\[Rule]", 
      RowBox[{"1", "/", "xh"}]}], ",", 
     RowBox[{"r", "\[Rule]", 
      RowBox[{"1", "/", "x"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"E1b", "=", 
  RowBox[{"Simplify", "[", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "E1"}], "/.", "ruleV"}], 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["xh", "6"]], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "x"], "-", 
        FractionBox["1", "xh"]}], ")"}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}], 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"]}]]}]], " "}]], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"E2b", "=", 
  RowBox[{"Simplify", "[", 
   FractionBox[
    RowBox[{"E2", "/.", "ruleV"}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "x"], "-", 
        FractionBox["1", "xh"]}], ")"}], 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}], 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"]}]]}]], " "}]], "]"}]}]}], "Input",
 CellChangeTimes->{{3.570292160504057*^9, 3.5702922427396507`*^9}, {
   3.570292282713088*^9, 3.570292366569953*^9}, {3.570292396790045*^9, 
   3.570292474926083*^9}, {3.5702929034203033`*^9, 3.5702929061963863`*^9}, {
   3.570293435535921*^9, 3.5702934403603773`*^9}, {3.5702935440930357`*^9, 
   3.5702935576217117`*^9}, 3.570293758545892*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"l", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "l"}], ")"}], " ", 
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["xh", "6"]}], "-", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", "+", "l", "+", 
        SuperscriptBox["l", "2"]}], ")"}], " ", 
      SuperscriptBox["x", "3"], " ", 
      SuperscriptBox["xh", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["xh", "2"]}], ")"}]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["x", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["xh", "2"]}], ")"}], "2"]}], "-", 
     RowBox[{"3", " ", "x", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["xh", "3"], "+", 
        SuperscriptBox["xh", "5"]}], ")"}]}], "+", 
     RowBox[{
      SuperscriptBox["xh", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"l", "+", 
        SuperscriptBox["l", "2"], "-", 
        SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}], " ", 
   RowBox[{"q", "[", "x", "]"}]}], "-", 
  RowBox[{"48", " ", "\[Pi]", " ", 
   SuperscriptBox["x", "3"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["xh", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["xh", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["x", "2"], " ", 
      SuperscriptBox["xh", "3"]}], "+", 
     RowBox[{
      SuperscriptBox["x", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", "\[Alpha]", " ", 
   RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", " ", "xh"}], "+", 
      SuperscriptBox["xh", "2"], "+", 
      RowBox[{
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["xh", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SuperscriptBox["xh", "2"], " ", "\[Omega]", " ", 
       RowBox[{"q", "[", "x", "]"}]}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "xh"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["q", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["xh", "2"]}], ")"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", " ", "xh"}], "+", 
       SuperscriptBox["xh", "2"], "+", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["xh", "3"], " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], ")"}], " ", 
       
       RowBox[{"q", "[", "x", "]"}]}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "xh"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}], "-", 
            RowBox[{"xh", " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               SuperscriptBox["xh", "2"], "+", 
               RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], 
              ")"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"x", "-", "xh"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            SuperscriptBox["xh", "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["q", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SuperscriptBox["xh", "2"]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{{3.570293544434394*^9, 3.570293558182721*^9}, 
   3.570293759539811*^9, 3.5702966561165247`*^9, 3.570320806550293*^9}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "l"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"2", "+", "l"}], ")"}], " ", 
    SuperscriptBox["x", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      SuperscriptBox["xh", "2"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["xh", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["xh", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", "\[Alpha]", " ", 
    
    RowBox[{"q", "[", "x", "]"}]}], 
   SuperscriptBox["xh", "6"]], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["xh", "3"]}], "-", 
         RowBox[{
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox["xh", "3"]}], "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["xh", "6"]}], "+", 
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox["xh", "6"]}], "+", 
         RowBox[{
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["xh", "3"], "+", 
            SuperscriptBox["xh", "5"]}], ")"}]}], "+", 
         RowBox[{"144", " ", "l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", "\[Pi]", " ", 
          SuperscriptBox["x", "8"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["xh", "2"]}], ")"}], "2"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], 
      RowBox[{
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["xh", "9"]}]], "+", 
     SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
   RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"x", " ", "xh"}], "+", 
      SuperscriptBox["xh", "2"], "+", 
      RowBox[{
       SuperscriptBox["x", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["xh", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["x", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "\[ImaginaryI]"}], " ", 
       SuperscriptBox["xh", "2"], " ", "\[Omega]", " ", 
       RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "xh"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["\[CurlyPhi]", "\[Prime]",
         MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox["xh", "6"], " ", 
    RowBox[{"(", 
     RowBox[{"3", "+", 
      SuperscriptBox["xh", "2"]}], ")"}]}]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"x", " ", "xh"}], "+", 
       SuperscriptBox["xh", "2"], "+", 
       RowBox[{
        SuperscriptBox["x", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[ImaginaryI]", " ", 
       SuperscriptBox["xh", "3"], " ", "\[Omega]", " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], ")"}], " ", 
       
       RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "+", 
      RowBox[{"x", " ", 
       RowBox[{"(", 
        RowBox[{"x", "-", "xh"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         SuperscriptBox["xh", "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}], "-", 
            RowBox[{"xh", " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               SuperscriptBox["xh", "2"], "+", 
               RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], 
              ")"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["\[CurlyPhi]", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "+", 
         RowBox[{"x", " ", 
          RowBox[{"(", 
           RowBox[{"x", "-", "xh"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            SuperscriptBox["xh", "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["\[CurlyPhi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["x", "2"], " ", 
    SuperscriptBox["xh", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SuperscriptBox["xh", "2"]}], ")"}], "2"]}]]}]], "Output",
 CellChangeTimes->{{3.570293544434394*^9, 3.570293558182721*^9}, 
   3.570293759539811*^9, 3.5702966561165247`*^9, 3.5703208072104177`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Series", "Subsubsection",
 CellChangeTimes->{{3.570293591413066*^9, 3.570293592506198*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SERIES", "[", 
     RowBox[{
     "\[Omega]0_", ",", "l0_", ",", "\[Alpha]0_", ",", "q0_", ",", 
      "\[CurlyPhi]0_", ",", "rh0_", ",", "ORDH_", ",", "x0_"}], "]"}], ":=", 
    RowBox[{"(", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"param", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"param", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Omega]", "\[Rule]", "\[Omega]0"}], ",", 
         RowBox[{
          RowBox[{"qh", "[", "0", "]"}], "\[Rule]", "q0"}], ",", 
         RowBox[{
          RowBox[{"\[CurlyPhi]h", "[", "0", "]"}], "\[Rule]", 
          "\[CurlyPhi]0"}], ",", 
         RowBox[{"xh", "\[Rule]", 
          RowBox[{"1", "/", "rh0"}]}], ",", 
         RowBox[{"l", "\[Rule]", "l0"}], ",", 
         RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"q", "[", "x_", "]"}], ":=", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"qh", "[", "i", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "xh"}], ")"}], "i"]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", 
            RowBox[{"ORDH", "+", "20"}]}], "}"}]}], "]"}], "//.", "param"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"\[CurlyPhi]", "[", "x_", "]"}], ":=", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CurlyPhi]h", "[", "i", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "xh"}], ")"}], "i"]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", 
            RowBox[{"ORDH", "+", "20"}]}], "}"}]}], "]"}], "//.", "param"}]}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"ES1", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"l", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "l"}], ")"}], " ", 
            SuperscriptBox["x", "2"], " ", 
            SuperscriptBox["xh", "6"]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "+", "l", "+", 
              SuperscriptBox["l", "2"]}], ")"}], " ", 
            SuperscriptBox["x", "3"], " ", 
            SuperscriptBox["xh", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["xh", "2"]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["x", "4"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}], "2"]}], "-", 
           RowBox[{"3", " ", "x", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["xh", "3"], "+", 
              SuperscriptBox["xh", "5"]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox["xh", "6"], " ", 
            RowBox[{"(", 
             RowBox[{"l", "+", 
              SuperscriptBox["l", "2"], "-", 
              SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}], " ", 
         RowBox[{"q", "[", "x", "]"}]}], "-", 
        RowBox[{"48", " ", "\[Pi]", " ", 
         SuperscriptBox["x", "3"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["xh", "2"]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["xh", "3"]}], "-", 
           RowBox[{
            SuperscriptBox["x", "2"], " ", 
            SuperscriptBox["xh", "3"]}], "+", 
           RowBox[{
            SuperscriptBox["x", "3"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", "\[Alpha]", 
         " ", 
         RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "-", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", " ", "xh"}], "+", 
            SuperscriptBox["xh", "2"], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["xh", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["x", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SuperscriptBox["xh", "2"], " ", "\[Omega]", " ", 
             RowBox[{"q", "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{"x", "-", "xh"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               SuperscriptBox["xh", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["q", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            SuperscriptBox["xh", "2"]}], ")"}]}]], "-", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"3", "+", 
              SuperscriptBox["xh", "2"]}], ")"}], "2"]}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", " ", "xh"}], "+", 
            SuperscriptBox["xh", "2"], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["xh", "3"], " ", "\[Omega]", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              SuperscriptBox["xh", "2"], "+", 
              RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], ")"}], 
            " ", 
            RowBox[{"q", "[", "x", "]"}]}], "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{"x", "-", "xh"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              SuperscriptBox["xh", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"x", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    SuperscriptBox["xh", "2"]}], ")"}]}], "-", 
                 RowBox[{"xh", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    SuperscriptBox["xh", "2"], "+", 
                    RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], 
                   ")"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["q", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "+", 
              RowBox[{"x", " ", 
               RowBox[{"(", 
                RowBox[{"x", "-", "xh"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 SuperscriptBox["xh", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["q", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
          ")"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ES2", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", "l"}], ")"}], " ", 
          SuperscriptBox["x", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["xh", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["xh", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             SuperscriptBox["xh", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["x", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", "\[Alpha]",
           " ", 
          RowBox[{"q", "[", "x", "]"}]}], 
         SuperscriptBox["xh", "6"]], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox[
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", 
                SuperscriptBox["xh", "3"]}], "-", 
               RowBox[{
                SuperscriptBox["x", "2"], " ", 
                SuperscriptBox["xh", "3"]}], "+", 
               RowBox[{
                SuperscriptBox["x", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["xh", "6"]}], "+", 
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}], " ", 
                SuperscriptBox["x", "2"], " ", 
                SuperscriptBox["xh", "6"]}], "+", 
               RowBox[{
                SuperscriptBox["x", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["xh", "3"], "+", 
                  SuperscriptBox["xh", "5"]}], ")"}]}], "+", 
               RowBox[{"144", " ", "l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}], " ", "\[Pi]", " ", 
                SuperscriptBox["x", "8"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   SuperscriptBox["xh", "2"]}], ")"}], "2"], " ", 
                SuperscriptBox["\[Alpha]", "2"]}]}], ")"}]}], 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             SuperscriptBox["xh", "9"]}]], "+", 
           SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
         RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "+", 
        FractionBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", " ", "xh"}], "+", 
            SuperscriptBox["xh", "2"], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["xh", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["x", "3"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", 
             SuperscriptBox["xh", "2"], " ", "\[Omega]", " ", 
             RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
             RowBox[{"(", 
              RowBox[{"x", "-", "xh"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               SuperscriptBox["xh", "2"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[CurlyPhi]", "\[Prime]",
               MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}], 
         RowBox[{
          SuperscriptBox["x", "2"], " ", 
          SuperscriptBox["xh", "6"], " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            SuperscriptBox["xh", "2"]}], ")"}]}]], "+", 
        RowBox[{
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["x", "2"], " ", 
           SuperscriptBox["xh", "6"], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"3", "+", 
              SuperscriptBox["xh", "2"]}], ")"}], "2"]}]], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"x", " ", "xh"}], "+", 
            SuperscriptBox["xh", "2"], "+", 
            RowBox[{
             SuperscriptBox["x", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["xh", "2"]}], ")"}]}]}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[ImaginaryI]", " ", 
            SuperscriptBox["xh", "3"], " ", "\[Omega]", " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              SuperscriptBox["xh", "2"], "+", 
              RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], ")"}], 
            " ", 
            RowBox[{"\[CurlyPhi]", "[", "x", "]"}]}], "+", 
           RowBox[{"x", " ", 
            RowBox[{"(", 
             RowBox[{"x", "-", "xh"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"3", "+", 
              SuperscriptBox["xh", "2"]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"x", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    SuperscriptBox["xh", "2"]}], ")"}]}], "-", 
                 RowBox[{"xh", " ", 
                  RowBox[{"(", 
                   RowBox[{"3", "+", 
                    SuperscriptBox["xh", "2"], "+", 
                    RowBox[{"\[ImaginaryI]", " ", "xh", " ", "\[Omega]"}]}], 
                   ")"}]}]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[CurlyPhi]", "\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}], "+", 
              RowBox[{"x", " ", 
               RowBox[{"(", 
                RowBox[{"x", "-", "xh"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"3", "+", 
                 SuperscriptBox["xh", "2"]}], ")"}], " ", 
               RowBox[{
                SuperscriptBox["\[CurlyPhi]", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "x", "]"}]}]}], ")"}]}]}], 
          ")"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"ss", "=", 
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"ES1", ",", "ES2"}], "}"}], "//.", "param"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"xh", "/.", "param"}], ",", "ORDH"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"yh", "=", 
       RowBox[{"Union", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"qh", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "ORDH"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"\[CurlyPhi]h", "[", "i", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "ORDH"}], "}"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"eqs", "=", 
       RowBox[{"Union", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"SeriesCoefficient", "[", 
             RowBox[{
              RowBox[{"ss", "[", 
               RowBox[{"[", "1", "]"}], "]"}], ",", "i"}], "]"}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "ORDH"}], "}"}]}], "]"}], ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"SeriesCoefficient", "[", 
             RowBox[{
              RowBox[{"ss", "[", 
               RowBox[{"[", "2", "]"}], "]"}], ",", "i"}], "]"}], "\[Equal]", 
            "0"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "ORDH"}], "}"}]}], "]"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"systH", "=", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{"eqs", ",", "yh"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"param", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[Omega]", "\[Rule]", "\[Omega]0"}], ",", 
           RowBox[{
            RowBox[{"qh", "[", "0", "]"}], "\[Rule]", "q0"}], ",", 
           RowBox[{
            RowBox[{"\[CurlyPhi]h", "[", "0", "]"}], "\[Rule]", 
            "\[CurlyPhi]0"}], ",", 
           RowBox[{"xh", "\[Rule]", 
            RowBox[{"1", "/", "rh0"}]}], ",", 
           RowBox[{"l", "\[Rule]", "l0"}], ",", 
           RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "}"}]}], ";"}], 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"qn", "=", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"qh", "[", "i", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "xh"}], ")"}], "i"]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "ORDH"}], "}"}]}], "]"}], "//.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "systH"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"\[CurlyPhi]n", "=", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CurlyPhi]h", "[", "i", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"x", "-", "xh"}], ")"}], "i"]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "ORDH"}], "}"}]}], "]"}], "//.", 
        RowBox[{"Union", "[", 
         RowBox[{"param", ",", "systH"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"qn", ",", "\[CurlyPhi]n"}], "}"}], "/.", 
       RowBox[{"x", "\[Rule]", "x0"}]}]}], "\[IndentingNewLine]", ")"}]}], 
   ";"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.570293593975128*^9, 3.570293812194145*^9}, {
   3.570293971174427*^9, 3.570293981216717*^9}, {3.570294032519346*^9, 
   3.570294042296153*^9}, 3.5702940961793423`*^9, {3.570294148983176*^9, 
   3.5702943982659397`*^9}, {3.570294871499394*^9, 3.5702948918176603`*^9}, 
   3.570295026100575*^9, {3.5702951139897823`*^9, 3.570295116507987*^9}, {
   3.5702951751988583`*^9, 3.570295178869514*^9}, {3.5702953193084*^9, 
   3.570295338371564*^9}, {3.57029538384818*^9, 3.570295388524293*^9}, {
   3.570296672264205*^9, 3.570296682336008*^9}}],

Cell["Let\[CloseCurlyQuote]s try it for a given \[Omega]:", "Text",
 CellChangeTimes->{{3.571520363956361*^9, 3.571520369312929*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SERIES", "[", 
  RowBox[{
   RowBox[{"0.1", "-", 
    RowBox[{"0.1", " ", "I"}]}], ",", "2", ",", "0.1", ",", "1", ",", "0", 
   ",", "50", ",", "10", ",", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], "]"}]], "Input",
 CellChangeTimes->{{3.570293992722294*^9, 3.570294006860631*^9}, {
   3.57029404653518*^9, 3.570294052143545*^9}, {3.570294409455348*^9, 
   3.570294411474814*^9}, {3.570294894836274*^9, 3.570294898084653*^9}, 
   3.570295028893929*^9, {3.570295152935359*^9, 3.570295235100623*^9}, {
   3.570295267374958*^9, 3.570295275482521*^9}, {3.5702966896674757`*^9, 
   3.5702966946600857`*^9}, 3.570320871062501*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"RowReduce", "::", "luc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Result for \[NoBreak]\\!\\(RowReduce\\)\[NoBreak] of badly \
conditioned matrix \[NoBreak]\\!\\({\\(\\({\\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(-1.4384637696`*^-6\\)\\) + \
\\(\\(1.920256`*^-9\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.00007198080256` \[VeryThinSpace]\\)\\) + \
\\(\\(6.3829356085855254`*^-12\\\\ \[ImaginaryI]\\)\\)\\)\\)}\\)\\), \\(\\(\
\[LeftSkeleton] 18 \[RightSkeleton]\\)\\), \
\\(\\({\\(\\(2.2502999999999995`*^6 - \\(\\(300.04`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(1.9356872678523532`*^8 - \
\\(\\(13505.499733368886`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(6.754669165986119`*^9 - \\(\\(425131.68244145246`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(1.156064934340895`*^11 + \
\\(\\(620750.2888207557`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\[LeftSkeleton] \
14 \[RightSkeleton]\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\)}\\)\\)}\\)\\n\[NoBreak] may contain significant \
numerical errors. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/luc\\\", ButtonNote -> \
\\\"RowReduce::luc\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{
  3.570295391266334*^9, {3.5702966856294928`*^9, 3.570296695057675*^9}, 
   3.570320823910181*^9, 3.570320871422009*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.0487385998051496`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.0017769880527646596`", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{"0.0024826810605012447`", "\[VeryThinSpace]", "+", 
    RowBox[{"7.551104985272881`*^-6", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5702951826931133`*^9, 3.57029523649964*^9}, 
   3.5702952695357113`*^9, {3.570295311646226*^9, 3.570295324437428*^9}, {
   3.570295373831747*^9, 3.570295391267427*^9}, {3.570296685633061*^9, 
   3.570296695060727*^9}, 3.570320823913829*^9, 3.570320871425997*^9}]
}, Open  ]],

Cell["\<\
We define the determinant obtained by using the basis (1,0) and (0,1) of the \
initial coefficients.\
\>", "Text",
 CellChangeTimes->{{3.570322038475915*^9, 3.57032206127002*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DET", "[", 
   RowBox[{
   "\[Omega]0_", ",", "l0_", ",", "\[Alpha]0_", ",", "rh0_", ",", "ORDH_", 
    ",", "x0_"}], "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S10", "=", 
     RowBox[{"SERIES", "[", 
      RowBox[{
      "\[Omega]0", ",", "l0", ",", "\[Alpha]0", ",", "1", ",", "0", ",", 
       "rh0", ",", "ORDH", ",", "x0"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"a11", "=", 
     RowBox[{"S10", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"a12", "=", 
     RowBox[{"S10", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"S01", "=", 
     RowBox[{"SERIES", "[", 
      RowBox[{
      "\[Omega]0", ",", "l0", ",", "\[Alpha]0", ",", "0", ",", "1", ",", 
       "rh0", ",", "ORDH", ",", "x0"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"a21", "=", 
     RowBox[{"S01", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"a22", "=", 
     RowBox[{"S01", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Det", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"a11", ",", "a12"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a21", ",", "a22"}], "}"}]}], "}"}], "]"}]}], 
   "\[IndentingNewLine]", ")"}]}]], "Input",
 CellChangeTimes->{{3.570320826955655*^9, 3.570320904530898*^9}, {
  3.570321054474782*^9, 3.570321101848658*^9}}],

Cell["Let\[CloseCurlyQuote]s try it:", "Text",
 CellChangeTimes->{{3.5715203795121527`*^9, 3.571520381485792*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DET", "[", 
  RowBox[{
   RowBox[{"0.1", "-", 
    RowBox[{"0.1", " ", "I"}]}], ",", "2", ",", "0.1", ",", "50", ",", "10", 
   ",", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], "]"}]], "Input",
 CellChangeTimes->{{3.5703211086975813`*^9, 3.57032113205902*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"RowReduce", "::", "luc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Result for \[NoBreak]\\!\\(RowReduce\\)\[NoBreak] of badly \
conditioned matrix \[NoBreak]\\!\\({\\(\\({\\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(-1.4384637696`*^-6\\)\\) + \
\\(\\(1.920256`*^-9\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.00007198080256` \[VeryThinSpace]\\)\\) + \
\\(\\(6.3829356085855254`*^-12\\\\ \[ImaginaryI]\\)\\)\\)\\)}\\)\\), \\(\\(\
\[LeftSkeleton] 18 \[RightSkeleton]\\)\\), \
\\(\\({\\(\\(2.2502999999999995`*^6 - \\(\\(300.04`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(1.9356872678523532`*^8 - \
\\(\\(13505.499733368886`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(6.754669165986119`*^9 - \\(\\(425131.68244145246`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(1.156064934340895`*^11 + \
\\(\\(620750.2888207557`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\[LeftSkeleton] \
14 \[RightSkeleton]\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\)}\\)\\)}\\)\\n\[NoBreak] may contain significant \
numerical errors. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/luc\\\", ButtonNote -> \
\\\"RowReduce::luc\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.570321132393619*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"RowReduce", "::", "luc"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Result for \[NoBreak]\\!\\(RowReduce\\)\[NoBreak] of badly \
conditioned matrix \[NoBreak]\\!\\({\\(\\({\\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \
\\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \
\[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\
\\\\ \[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(-1.4384637696`*^-6\\)\\) + \
\\(\\(1.9202560000000005`*^-9\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(\\(\\(-1.448418049792504`*^-7\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\
\\)\\)}\\)\\), \\(\\({\\(\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\), \\(\\(\
\[LeftSkeleton] 16 \[RightSkeleton]\\)\\), \\(\\({\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)}\\)\\), \\(\\({\\(\\(2.2503`*^6 - \
\\(\\(300.0400000000001`\\\\ \[ImaginaryI]\\)\\)\\)\\), \
\\(\\(1.9356872678523535`*^8 - \\(\\(13505.499733368884`\\\\ \[ImaginaryI]\\)\
\\)\\)\\), \\(\\(6.754669165986119`*^9 - \\(\\(425131.6824414524`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\[LeftSkeleton] 15 \[RightSkeleton]\\)\\), \
\\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \[ImaginaryI]\\)\\)\\)\
\\), \\(\\(\\(\\(0.` \[VeryThinSpace]\\)\\) + \\(\\(0.`\\\\ \
\[ImaginaryI]\\)\\)\\)\\), \\(\\(\\(\\(-5.372883875899879`*^21\\)\\) - \
\\(\\(1.7873054714888402`*^18\\\\ \[ImaginaryI]\\)\\)\\)\\)}\\)\\)}\\)\\n\
\[NoBreak] may contain significant numerical errors. \\!\\(\\*ButtonBox[\\\"\
\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/luc\\\", ButtonNote -> \
\\\"RowReduce::luc\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.5703211324278097`*^9}],

Cell[BoxData[
 RowBox[{"0.4218136171099582`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.0145699264023003`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.570321109159111*^9, 3.57032113242976*^9}}]
}, Open  ]],

Cell["Example:", "Text",
 CellChangeTimes->{{3.5703220680843077`*^9, 3.570322069358639*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Xg", "=", 
     RowBox[{"4.06435161237486`", "\[VeryThinSpace]", "-", 
      RowBox[{"2.2284177126256726`", " ", "\[ImaginaryI]"}]}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"**", 
      RowBox[{"*", " ", "GRAVITATIONAL"}]}], " ", "****)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"Xg", "=", 
     RowBox[{"3.1119271895540463`", "\[VeryThinSpace]", "-", 
      RowBox[{"2.2939580343810473`", " ", "\[ImaginaryI]"}]}]}], ";", 
    RowBox[{"(*", 
     RowBox[{"**", 
      RowBox[{"*", " ", "SCALAR"}]}], " ", "****)"}], "\[IndentingNewLine]", 
    RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ff", "[", 
      RowBox[{"XX_", "?", "NumberQ"}], "]"}], ":=", 
     RowBox[{"DET", "[", 
      RowBox[{"XX", ",", "2", ",", "0.03", ",", "1", ",", "60", ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"FindRoot", "[", 
    RowBox[{
     RowBox[{"ff", "[", "XX", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"XX", ",", "Xg"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.570294254211256*^9, 3.570294275349777*^9}, {
  3.570294462625247*^9, 3.570294550387331*^9}, {3.570294797169606*^9, 
  3.570294819984087*^9}, {3.5702949018756227`*^9, 3.5702949019523907`*^9}, {
  3.570295398503376*^9, 3.570295462377245*^9}, {3.570295519396896*^9, 
  3.570295586714113*^9}, {3.5702967053666286`*^9, 3.570296708456729*^9}, {
  3.570296744272834*^9, 3.570296794834118*^9}, {3.570321141981832*^9, 
  3.570321231739822*^9}, {3.5703215923814707`*^9, 3.570321592459268*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"XX", "\[Rule]", 
   RowBox[{"3.6175439816240686`", "\[VeryThinSpace]", "-", 
    RowBox[{"2.2455473391794696`", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.570294252337426*^9, 3.570294294330287*^9}, {
   3.570294803684669*^9, 3.5702948205503807`*^9}, 3.5702949144987907`*^9, {
   3.570295399798562*^9, 3.570295466097844*^9}, 3.5702955785710983`*^9, 
   3.57029671320434*^9, {3.570296749181263*^9, 3.5702967956940613`*^9}, {
   3.570321168418255*^9, 3.570321238020735*^9}, 3.570321612907523*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tracking:", "Subsubsection",
 CellChangeTimes->{{3.5702956224259653`*^9, 3.570295624688361*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xi", "=", "0.01"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xf", "=", "0.07"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim", "=", "30"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx", "=", 
   FractionBox[
    RowBox[{"xf", "-", "xi"}], "dim"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"Null", ",", 
     RowBox[{"{", "dim", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xx", "=", "xi"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rh00", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"l00", "=", "2"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Xg", "=", 
   RowBox[{"4.06435161237486`", "\[VeryThinSpace]", "-", 
    RowBox[{"2.2284177126256726`", " ", "\[ImaginaryI]"}]}]}], ";", 
  RowBox[{"(*", 
   RowBox[{"**", 
    RowBox[{"*", " ", "GRAVITATIONAL"}]}], " ", "****)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Xg", "=", 
   RowBox[{"3.1119271895540463`", "\[VeryThinSpace]", "-", 
    RowBox[{"2.2939580343810473`", " ", "\[ImaginaryI]"}]}]}], ";", 
  RowBox[{"(*", 
   RowBox[{"**", 
    RowBox[{"*", " ", "SCALAR"}]}], " ", "****)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", "*****)"}], "\[IndentingNewLine]", 
  RowBox[{"Monitor", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"ii", "=", "1"}], ",", 
      RowBox[{"ii", "<", 
       RowBox[{"dim", "+", "1"}]}], ",", "\[IndentingNewLine]", 
      RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ff", "[", 
         RowBox[{"XX_", "?", "NumberQ"}], "]"}], ":=", 
        RowBox[{"DET", "[", 
         RowBox[{"XX", ",", "l00", ",", "xx", ",", "rh00", ",", "30", ",", 
          SuperscriptBox["10", 
           RowBox[{"-", "3"}]]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Z", "=", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{"ff", "[", "XX", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"XX", ",", "Xg"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Xg", "=", 
        RowBox[{"XX", "/.", "Z"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"check", "=", 
        RowBox[{"Abs", "[", 
         RowBox[{"ff", "[", "Xg", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{
        RowBox[{"TT", "[", 
         RowBox[{"[", "ii", "]"}], "]"}], "=", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"N", "[", "xx", "]"}], ",", "Xg", ",", "check"}], "}"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"ii", "++"}], ";", "\[IndentingNewLine]", 
       RowBox[{"xx", "=", 
        RowBox[{"xx", "+", "dx"}]}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"ii", ",", 
      RowBox[{"N", "[", "xx", "]"}], ",", "Xg", ",", "check"}], "}"}]}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5702956329727907`*^9, 3.570295821810349*^9}, {
  3.5702958886270103`*^9, 3.570295889809971*^9}, {3.570296051314724*^9, 
  3.570296061129238*^9}, {3.5702967676330643`*^9, 3.570296826694632*^9}, {
  3.570296958862018*^9, 3.5702969601077547`*^9}, {3.57029706057942*^9, 
  3.570297066686092*^9}, {3.5702971207258177`*^9, 3.570297121457615*^9}, {
  3.570297224542398*^9, 3.57029722491726*^9}, {3.570297268485813*^9, 
  3.570297269551116*^9}, {3.570321246898549*^9, 3.570321272605938*^9}, {
  3.570321506166724*^9, 3.570321507097557*^9}, {3.570321621846157*^9, 
  3.570321632634933*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"TT2", "=", "TT"}], ";"}]], "Input",
 CellChangeTimes->{{3.570296001768231*^9, 3.570296005177911*^9}, 
   3.5702969628015327`*^9, {3.570297123961182*^9, 3.57029712406647*^9}, 
   3.570297272214025*^9, {3.570321509542758*^9, 3.570321509632329*^9}, 
   3.5703218605941257`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Omega]R2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"TT", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"Re", "[", 
        RowBox[{
         RowBox[{"TT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "TT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Omega]I2", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"TT", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Im", "[", 
         RowBox[{
          RowBox[{"TT", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "TT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.570296863928026*^9, 3.5702968673910522`*^9}, {
  3.570296926050879*^9, 3.570296969827024*^9}, {3.570297125890373*^9, 
  3.570297129618924*^9}, {3.5702971849936323`*^9, 3.570297195910754*^9}, {
  3.570297274445484*^9, 3.5702972779178543`*^9}, {3.570321275185649*^9, 
  3.570321275377976*^9}, {3.5703215120254803`*^9, 3.570321512844791*^9}, {
  3.570321862408938*^9, 3.5703218634126043`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "****)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Omega]R1", ",", "\[Omega]R2"}], "}"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Alpha]/\!\(\*SuperscriptBox[SubscriptBox[\(r\), \(h\)], \
\(2\)]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(\[Omega]\), \(R\)]\)\!\(\*SuperscriptBox[\
\(L\), \(2\)]\)/\!\(\*SubscriptBox[\(r\), \(h\)]\)\>\""}], "}"}]}], ",", 
       RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Omega]I1", ",", "\[Omega]I2"}], "}"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Alpha]/\!\(\*SuperscriptBox[SubscriptBox[\(r\), \(h\)], \
\(2\)]\)\>\"", ",", 
          "\"\<-\!\(\*SubscriptBox[\(\[Omega]\), \
\(I\)]\)\!\(\*SuperscriptBox[\(L\), \(2\)]\)/\!\(\*SubscriptBox[\(r\), \(h\)]\
\)\>\""}], "}"}]}], ",", 
       RowBox[{"Mesh", "\[Rule]", "None"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2"}], "}"}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "900"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.570295833110599*^9, 3.570295878638829*^9}, {
   3.570295932753063*^9, 3.570295996000594*^9}, {3.570296870556739*^9, 
   3.570296873086219*^9}, {3.570296946382942*^9, 3.570296980830052*^9}, {
   3.5702970203066797`*^9, 3.5702970280625763`*^9}, 3.570297131122694*^9, {
   3.5702972816630697`*^9, 3.5702973772212973`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQXS2yzv1hVYu90NGk7RJOAg6/6rL2lEzusBeWefWu
QEvAofKlmiHHmh57+WmMt8X4BBz+rPx4yTdpgv0q/Qkh4df5HWzu+/dOz5tk
z32QfVpFA79DDdi8KfZC0+5nanDyO+zx5GHSbp9m71Ak4XXIls/hD9j8GfaT
LsmrfnnL62Cz5UTZvvmz7EunmRVfkOdzqAHbN8deSetnzJQ4Poc9cq2vA3fM
s++Njij/sYjP4R/Y/gX2GzyN6j++4nOYd0RhQ1HGQvvmxZ8nNpnyO9iB3bPI
Xvbic3fBJn6Hez9BFi62j/knMM34Ar9DHdh9S+w9DkqfP8sv4CCnf1eFrXGp
/d7Pr++yWQg47AO7d5n9wq6LDWsTBBziUqyBJi63/6LIJrC+U8DhH9j9K+xv
Nquw/N0k4DBvJgistD8ukq7ae0fAwQ7sn1X2s5jiLkWxCTrcO/c9+PHS1fa2
k/4eyjQQdKgD+2+NfV2C+d5TUYIOcixhfLqb1tqfvrWucVGroMM+sH/X2a9x
2NdgtFHQIc4SZOB6+/viD8Ue3hV0+A/2/wb7Q9+OX7DiEXLwN+90THi6wb5l
X4DUHRshh/ng8Nho3/fYb5VkgZADAJPI2Uc=
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQXS2yzv1hVYu99TEtvUUunA6/6rL2lEzusGfVVdx3
u4PTofKlmiHHmh579jPVt1Y84nT4s/LjJd+kCfbL1e57RAZzOdjc9++dnjfJ
nuWEJ7f+fS6HGrB5U+xDVJfIc0zmdtjjycOk3T7N/gOv/XGjhTwOf8Dmz7B3
SVPOeWzB62Cz5UTZvvmz7H/IVzLIBvM61IDtm2PfMuvggkfJvA575FpfB+6Y
Z595S3fHvUJeh39g+xfYt0upWMyu43WYd0RhQ1HGQvvuZ4vmrOzidbADu2eR
vVV6oJPXNF6Hez9BFi62n7FM4+eshbwOdWD3LbG3Dt9es2INr4Oc/l0Vtsal
9q4FE2PLtvM67AO7d5n9lZVWosyHeB3iUqyBJi63b7cOC/U6A7Qf7P4V9lfe
fipwuwa0fyYIrLSvVNfw/ngfaD/YP6vsX0+9zOr6Emj/ue/Bj5eutt+dKzLV
5hPQfrD/1tjLXz3rf+UX0H6WMD7dTWvtLXY96+Ji5nPYB/bvOnumyW/sHnDx
OcRZggxcb3+hhm1RpBCfw3+w/zfYH/nCUl8nyefgb97pmPB0g32/2veHkQp8
DvPB4bHRPo1hRd4PNT4HAKLs1uI=
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0.01, 3.2},
      Frame->True,
      FrameLabel->{
        FormBox[
        "\"\[Alpha]/\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(h\\)], \
\\(2\\)]\\)\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Omega]\\), \
\\(R\\)]\\)\\!\\(\\*SuperscriptBox[\\(L\\), \
\\(2\\)]\\)/\\!\\(\\*SubscriptBox[\\(r\\), \\(h\\)]\\)\"", TraditionalForm]},
      PlotRange->{{0.01, 0.06800000000000005}, {3.15851245945012, 
       4.609472905220981}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQXS2yzv1hVYv97BWuOfuOMzr8qsvaUzK5w35rrz2f
zmxGh8qXaoYca3rs5f4tV7iQzujwZ+XHS75JE+zjnskuXqHL6GBz3793et4k
e9O5eXYTXjM41IDNm2IfcI5/XcYcBoc9njxM2u3T7Juu5m5xF2Fw+AM2f4Z9
//uDs53T/trbbDlRtm/+LPtJlXfFZxX/tq8B2zfHXtC4+Oieez/t98i1vg7c
Mc9+Py9j39LqH/b/wPYvsBfX+qj62PK7/bwjChuKMhbaX9j+VVpF8Ju9Hdg9
i+xfl21eXvLni/29nyALF9urFkstn/Djs30d2H1L7O2erOrXYP5sL6d/V4Wt
cak918K5L5qlPtnvA7t3mf2zy3uKfG0/2selWANNXG5/x+rSy+KsD/b/wO5f
YW+v/WarttN7+3kzQWClvVPRx/AXB97a24H9s8o+RJ5j72X/N/b3zn0Pfrx0
tb3Ulut6V96+sq8D+2+NfTErzw+BWS/t5VjC+HQ3rbW/vF5/gUbIC/t9YP+u
sy/01UxYJfPcPs4SZOB6+7tfuVYwf3tq/x/s/w32s9iW7NJ79sTe37zTMeHp
BvuPwVeVp/58bD8fHB4b7b+u/++33v2xPQAKSe/o
         "]]}, 
       {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGCQA2IQXS2yzv1hVYu9g9T7o/5bmBx+1WXtKZncYW+m6XQl
x5nJofKlmiHHmh57g53SuzmuMTr8Wfnxkm/SBHvRib27IgoYHWzu+/dOz5tk
n/FaT1xWjNGhBmzeFPvt0+X3fz/L4LDHk4dJu32afdgFk1cLjzA4/AGbP8Ne
/uPvyy2zgPq3nCjbN3+WvfjcHWce8TE51IDtm2Pv6y/zYGoUk8MeudbXgTvm
2RfcnelaMZnJ4R/Y/gX2uyvLnvQcZHKYd0RhQ1HGQvu+GdfrDrxgcrADu2eR
vfTsA1f8uJkd7v0EWbjYftq+FKY5WswOdWD3LbHnZjIJnuzO7CCnf1eFrXGp
ffYGu7nXkpgd9oHdu8w+9ugjjxs1zA5xKdZAE5fb/7hTuf7VVGaHf2D3r7D/
N7N8s+c6Zod5M0Fgpf0nHxcWxWPMDnZg/6yyz7a+nzDhLtD+c9+DHy9dbX9h
Xc+CdV+A9oP9t8be4cAl5h5uFgc5ljA+3U1r7XetnaFvosTisA/s33X2vFNk
1DdYsDjEWYIMXG//YSrPVA5/Fof/YP9vsO/S/LTeI5XFwd+80zHh6Qb7eRK5
PxurWRzmg8Njo73n9vhvFyayOAAAnJHbpg==
         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0.01, 1.},
      Frame->True,
      FrameLabel->{
        FormBox[
        "\"\[Alpha]/\\!\\(\\*SuperscriptBox[SubscriptBox[\\(r\\), \\(h\\)], \
\\(2\\)]\\)\"", TraditionalForm], 
        FormBox[
        "\"-\\!\\(\\*SubscriptBox[\\(\[Omega]\\), \
\\(I\\)]\\)\\!\\(\\*SuperscriptBox[\\(L\\), \
\\(2\\)]\\)/\\!\\(\\*SubscriptBox[\\(r\\), \\(h\\)]\\)\"", TraditionalForm]},
      PlotRange->{{0.01, 0.06800000000000005}, {0.6025005858368774, 
       2.571199345394153}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {576., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->900,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.5702973238313513`*^9, 3.570297377650646*^9}, 
   3.570321562357952*^9, 3.570321930975391*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1366, 725},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 573, 10, 95, "Subtitle"],
Cell[CellGroupData[{
Cell[1177, 36, 100, 1, 71, "Section"],
Cell[1280, 39, 92, 1, 29, "Text"],
Cell[1375, 42, 1895, 60, 269, "Input"],
Cell[CellGroupData[{
Cell[3295, 106, 424, 11, 48, "Input"],
Cell[3722, 119, 481, 14, 53, "Output"]
}, Open  ]],
Cell[4218, 136, 92, 1, 29, "Text"],
Cell[4313, 139, 828, 24, 55, "Input"],
Cell[5144, 165, 2654, 85, 131, "Input"],
Cell[7801, 252, 154, 2, 29, "Text"],
Cell[CellGroupData[{
Cell[7980, 258, 3368, 103, 199, "Input"],
Cell[11351, 363, 5093, 157, 136, "Output"],
Cell[16447, 522, 5913, 180, 208, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22397, 707, 97, 1, 28, "Subsubsection"],
Cell[22497, 710, 19017, 502, 803, "Input"],
Cell[41517, 1214, 133, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[41675, 1219, 658, 13, 35, "Input"],
Cell[42336, 1234, 3187, 51, 218, "Message"],
Cell[45526, 1287, 604, 11, 35, "Output"]
}, Open  ]],
Cell[46145, 1301, 189, 4, 28, "Text"],
Cell[46337, 1307, 1513, 39, 174, "Input"],
Cell[47853, 1348, 114, 1, 29, "Text"],
Cell[CellGroupData[{
Cell[47992, 1353, 293, 8, 35, "Input"],
Cell[48288, 1363, 3088, 49, 218, "Message"],
Cell[51379, 1414, 3110, 47, 122, "Message"],
Cell[54492, 1463, 206, 3, 29, "Output"]
}, Open  ]],
Cell[54713, 1469, 92, 1, 28, "Text"],
Cell[CellGroupData[{
Cell[54830, 1474, 1666, 37, 124, "Input"],
Cell[56499, 1513, 561, 10, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[57109, 1529, 102, 1, 28, "Subsubsection"],
Cell[57214, 1532, 3648, 91, 502, "Input"],
Cell[60865, 1625, 309, 6, 29, "Input"],
Cell[61177, 1633, 1612, 45, 48, "Input"],
Cell[CellGroupData[{
Cell[62814, 1682, 2145, 52, 111, "Input"],
Cell[64962, 1736, 4709, 96, 310, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
